@@ -1,5 +1,5 @@
 <?php
-/* $Id: japanese-sjis.inc.php 9925 2007-02-05 17:53:36Z lem9 $ */
+/* $Id: japanese-sjis.inc.php 11122 2008-02-13 12:33:49Z lem9 $ */
 
 /**
  * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
@@ -70,7 +70,6 @@ $strAscending = '';
 $strAtBeginningOfTable = 'e[u̐擪';
 $strAtEndOfTable = 'e[u̖';
 $strAttr = '';
-$strAutodetect = 'm';
 $strAutomaticLayout = 'CAEg';
 
 $strBack = '߂';
@@ -159,6 +158,7 @@ $strConnectionError = 'ڑł܂: ݒ肪ł';
 $strConnections = 'ڑ';
 $strConstraintsForDumped = '_ve[u̐';
 $strConstraintsForTable = 'e[u̐';
+$strControluserFailed = 'ݒt@Cɒ`ĂǗ[U(controluser)ł̐ڑɎs܂';
 $strCookiesRequired = 'NbL[LɂĂ';
 $strCopyDatabaseOK = 'f[^x[X %s  %s ɃRs[܂';
 $strCopy = 'Rs[';
@@ -184,8 +184,6 @@ $strCreationDates = '쐬/XV/';
 $strCriteria = '';
 $strCroatian = 'NA`A';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV IvV';
-$strCSVOptions = 'CSV IvV';
 $strCyrillic = 'LVA';
 $strCzech = '`FR';
 $strCzechSlovak = '`FR̃XoLA';
@@ -195,7 +193,6 @@ $strDatabaseEmpty = 'f[^x[Xł!';
 $strDatabaseExportOptions = 'f[^x[XGNX|[gIvV';
 $strDatabase = 'f[^x[X';
 $strDatabaseHasBeenDropped = 'f[^x[X %s 폜܂';
-$strDatabaseNoTable = '̃f[^x[Xɂ̓e[u܂!';
 $strDatabasesDropped = 'f[^x[X %s 𐳏ɍ폜܂';
 $strDatabases = 'f[^x[X';
 $strDatabasesStatsDisable = 'v𖳌ɂ';
@@ -241,7 +238,6 @@ $strDisplayOrder = '\\:';
 $strDisplayPDF = 'PDF XL[}\\';
 $strDoAQuery = '"query by example"s (ChJ[h: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL IvV';
 $strDocu = 'hLg';
 $strDoYouReally = '{Ɏs܂?';
 $strDropDatabaseStrongWarning = 'f[^x[XSɍ폜悤ƂĂ܂!';
@@ -279,8 +275,8 @@ $strErrorSaveTable = 'fUCi̍WۑƂɃG[܂';
 $strEscapeWildcards = '_  % ƂChJ[h𕶎ƂĎgpƂ \ ŃGXP[vĂ';
 $strEsperanto = 'GXyg';
 $strEstonian = 'GXgjA';
+$strEvent = 'Cxg';
 $strExcelEdition = 'Excel ̃GfBV';
-$strExcelOptions = 'Excel ̃IvV';
 $strExecuteBookmarked = 'ubN}[NꂽNGs';
 $strExplain = 'EXPLAIN ŊmF';
 $strExport = 'GNX|[g';
@@ -291,7 +287,7 @@ $strExtra = '̑';
 
 $strFailedAttempts = 's';
 $strFieldHasBeenDropped = 'tB[h %s 폜܂';
-$strFieldsEmpty = ' tB[hłB ';
+$strFieldInsertFromFileTempDirNotExists = 'Abv[hꂽt@C̈ړɎs܂BFAQ 1.11 B';
 $strFieldsEnclosedBy = 'tB[h͂݋L';
 $strFieldsEscapedBy = 'tB[h̃GXP[vL';
 $strFields = 'tB[h';
@@ -305,6 +301,7 @@ $strFileNameTemplateDescriptionServer = 'T[o';
 $strFileNameTemplateDescriptionTable = 'e[u';
 $strFileNameTemplateRemember = 'ev[gL';
 $strFileNameTemplate = 't@C̃ev[g';
+$strFiles = 't@C';
 $strFileToImport = 'C|[gt@C';
 $strFixed = 'Œ';
 $strFlushPrivilegesNote = ': phpMyAdmin  MySQL ̓e[u璼ڃ[U擾܂AƂœXVꍇ phpMyAdmin pĂe[u̓eƃT[o̓̓evȂȂ邱Ƃ܂̂ŁAƂ𑱂O %s[h%s Ă';
@@ -341,7 +338,7 @@ $strHasBeenCreated = '쐬܂';
 $strHaveToShow = 'ŒЂƂ͕\\JIĂ';
 $strHebrew = 'wuC';
 $strHelp = 'wv';
-$strHexForBinary = 'oCitB[hł 16 igp';
+$strHexForBLOB = 'BLOB16i\L𗘗p';
 $strHide         = 'B';
 $strHideShowAll = 'ׂĉB/\\';
 $strHideShowNoRelation = '[V̂Ȃe[uB/\\';
@@ -350,9 +347,7 @@ $strHomepageOfficial = 'phpMyAdmin ̃ItBVTCg';
 $strHostEmpty = 'zXgł!';
 $strHost = 'zXg';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 GNX|[gIvV';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 GNX|[gIvV';
 $strHungarian = 'nK[';
 
 $strIcelandic = 'ACXh';
@@ -369,13 +364,11 @@ $strImportFormat = 'C|[gt@Č`';
 $strImportSuccessfullyFinished = 'C|[g͐I܂B%d ̃NGs܂';
 $strIndex = 'CfbNX';
 $strIndexes = 'CfbNXTCY';
+$strIndexesSeemEqual = 'ȉ̃CfbNX͓̂̂悤Ɏv܂Bꂩ폜Ă :';
 $strIndexHasBeenDropped = 'CfbNX %s 폜܂';
 $strIndexName = 'CfbNX:';
 $strIndexType = 'CfbNX̎:';
-$strIndexWarningMultiple = '%s ƂL[J `%s` ɕ쐬܂';
-$strIndexWarningPrimary = 'J `%s`  PRIMARY L[ INDEX L[𗼕w肷邱Ƃ͂ł܂';
 $strIndexWarningTable = 'e[u `%s` ̃CfbNXɖ肪܂';
-$strIndexWarningUnique = 'J `%s`  UNIQUE L[ INDEX L[𗼕w肷邱Ƃ͂ł܂';
 $strInnoDBAutoextendIncrementDesc = 'Xy[XςɂȂƂɎIɃe[ugꍇɒǉe[uTCY';
 $strInnoDBAutoextendIncrement = 'gɒǉe[uTCY';
 $strInnoDBBufferPoolSizeDesc = 'InnoDB e[ũf[^CfbNXLbV̂Ɏgobt@';
@@ -425,7 +418,6 @@ $strKnownExternalBug = '%s ̋@\ɂ͊m̃oO܂B%s ';
 $strKorean = '؍';
 
 $strLandscape = '';
-$strLanguageFileNotFound = 't@Cu%1$sv܂';
 $strLanguageUnknown = 't@Co^Ă܂: %1$s';
 $strLanguage = '';
 $strLatchedPages = 'b`Ăy[W';
@@ -436,10 +428,8 @@ $strLatexContinuedCaption = 'e[ũLvV()';
 $strLatexIncludeCaption = 'e[ũLvV܂߂';
 $strLatexLabel = 'xL[';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX IvV';
 $strLatexStructure = 'e[u __TABLE__ ̍\';
 $strLatvian = 'grA';
-$strLDIImportOptions = 'LOAD DATA  CSV C|[gƂ̃IvV';
 $strLDI = 'LOAD DATA  CSV';
 $strLDILocal = 'LOCAL L[[hgp';
 $strLengthSet = '/l';
@@ -497,6 +487,7 @@ $strMyISAMSortBufferSize = '\[gobt@̃TCY';
 $strMySQLCharset = 'MySQL ̕Zbg';
 $strMysqlClientVersion = 'MySQL NCAg̃o[W';
 $strMySQLConnectionCollation = 'MySQL ̐ڑƍ';
+$strMysqlLibDiffersServerVersion = 'g PHP MySQL Cũo[W %s  MySQL T[õo[W %s ƈقȂ܂B͗\ȂsN\܂B';
 $strMySQLSaid = 'MySQL̃bZ[W: ';
 $strMySQLShowProcess = 'MySQL vZX̕\\';
 $strMySQLShowStatus = 'MySQL ̃^C';
@@ -542,14 +533,13 @@ $strNumSearchResultsTotal = '<b>v:</b> <i>%s</i> ';
 $strNumTables = 'e[u';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheetOptions = 'XvbhV[gIvV';
 $strOpenDocumentSpreadsheet = 'XvbhV[gJ';
 $strOpenDocumentText = 'eLXgJ';
-$strOpenDocumentTextOptions = 'eLXgIvV';
 $strOpenNewWindow = 'ʃEBhEŊJ';
 $strOperations = '';
 $strOperator = 'Zq';
 $strOptimizeTable = 'e[uœK';
+$strOptions = 'IvV';
 $strOr = '܂';
 $strOverhead = 'I[o[wbh';
 $strOverwriteExisting = '̃t@C͏㏑';
@@ -567,7 +557,6 @@ $strPassword = 'pX[h';
 $strPdfDbSchema = 'f[^x[X %s ̃XL[} - y[W %s';
 $strPdfInvalidTblName = '"%s" e[u݂͑܂!';
 $strPdfNoTables = 'e[u܂';
-$strPDFOptions = 'PDF IvV';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(ЂƂ̃e[ũf[^܂ރ|[g𐶐܂)';
 $strPDFReportTitle = '|[g̃^Cg';
@@ -635,6 +624,7 @@ $strPrivilegesReloaded = '𐳏Ƀ[h܂';
 $strProcedures = 'vVW';
 $strProcesses = 'vZX';
 $strProcesslist = 'vZXꗗ';
+$strProfiling = 'vt@CO';
 $strProtocolVersion = 'vgRo[W';
 $strPutColNames = '1 sڂɃtB[hǉ';
 
@@ -676,12 +666,15 @@ $strReplaceTable = 'e[uf[^ւt@C';
 $strReplication = 'vP[V';
 $strReset = 'Zbg';
 $strResourceLimits = '\[X̐';
+$strRestartInsertion = '%s s}ĊJ';
 $strReType = 'x͂Ă';
 $strRevoke = '';
 $strRevokeAndDelete = 'ׂĎă[U폜';
 $strRevokeAndDeleteDescr = 'USAGE ɂĂ͓[h܂Ŏc܂';
 $strRevokeMessage = '%s ̓܂';
 $strRomanian = '[}jA';
+$strRoutineReturnType = 'Ԃl̎';
+$strRoutines = '[`';
 $strRowLength = 's̒';
 $strRowsFrom = 'Jns';
 $strRowSize = ' s̃TCY ';
@@ -733,6 +726,7 @@ $strServer = 'T[o';
 $strServerTrafficNotes = '<b>T[ogtBbN</b>: ̕\\ MySQL T[oNȌ̃lbg[NgtBbN̓vł';
 $strServerVars = 'T[oϐƐݒl';
 $strServerVersion = 'T[õo[W';
+$strSessionStartupErrorGeneral = 'G[o߃ZbVJnł܂łBPHP EFuT[õOt@CɏoĂG[mFāAPHP 𐳂ݒ肵ĂB';
 $strSessionValue = 'ZbVl';
 $strSetEnumVal = 'tB[hʂuenumvȂusetv̏ꍇ̒l̏: \'a\',\'b\',\'c\'...<br />obNXbV("\")VONH[g("\'")܂߂Kvꍇ ( \\\\xyz  a\\\'b ̂悤) ̑OɃobNXbVtĂ';
 $strShowAll = 'ׂĕ\\';
@@ -822,7 +816,7 @@ $strShowStatusKey_readsDescr = 'fBXNL[ubN𕨗ǂݍ݂񐔁BKey_reads 傫̂͂炭 key
 $strShowStatusKey_write_requestsDescr = 'LbVɃL[ubN񂾃NGXg̐';
 $strShowStatusKey_writesDescr = 'fBXNɃL[ubN𕨗݂';
 $strShowStatusLast_query_costDescr = 'NGIveB}CU[̌vZɂAŌɃRpCꂽNG̑RXgBNG̃vςƂɃRXgǂς邩rƂɕ֗łBftHgl 0 ͂܂xNGRpCĂȂƂӖł';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'INSERT DELAY L[̒ŏ܂̂҂Ăs';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'INSERT DELAYED L[̒ŏ܂̂҂Ăs';
 $strShowStatusOpened_tablesDescr = 'JĂe[u̐BJĂe[uꍇ͂炭e[uLbV̒l܂';
 $strShowStatusOpen_filesDescr = 'JĂt@C̐';
 $strShowStatusOpen_streamsDescr = 'JĂXg[̐ (ɃŐL^pł)';
@@ -877,8 +871,6 @@ $strSpanish = 'XyC';
 $strSplitWordsWithSpace = 'eP͋󔒕(" ")ŋ؂Ă';
 $strSQLCompatibility = 'SQL݊[h';
 $strSQLExportType = 'GNX|[g`';
-$strSQLImportOptions = 'SQL IvV';
-$strSQLOptions = 'SQL IvV';
 $strSQLParserBugMessage = 'SQL p[TɃoO邱Ƃ肦܂A܂̓NG悭Ĉp̐ނɊԈႢȂmFĂBNH[gĂȂeLXg̈ɃoCit@CAbv[hNGsƂƂ肦܂BMySQL ̃R}hCC^tF[X𗘗păNGsĂ݂Ă悢ł傤B MySQL T[õG[o͂oĂ悤Ȃ̉͂ɖ𗧂܂BłȂAR}hCł͐̂Ƀp[Tł͎sꍇ́ASQL NG̓̓f[^ۂɖNĂNGЂƂɍi荞łAȉ́uCUTvZNVɃf[^YăoO񍐂𑗂Ă:';
 $strSQLParserUserError = 'SQL ɃG[悤łB MySQL T[õG[o͂oĂ悤Ȃ̉͂ɖ𗧂܂';
 $strSQLQuery = 's SQL';
@@ -900,7 +892,6 @@ $strStrucCSV = 'CSV f[^';
 $strStrucData = '\ƃf[^';
 $strStrucExcelCSV = 'MS Excel p CSV';
 $strStrucNativeExcel = 'MS Excel ̃lCeBu`';
-$strStrucNativeExcelOptions = 'Excel ̃lCeBuGNX|[gIvV';
 $strStrucOnly = '\̂';
 $strStructPropose = 'e[u\mF';
 $strStructure = '\';
@@ -966,6 +957,7 @@ $strTransformation_text_plain__imagelink = '摜ƃN\\܂BtB[hɂ̓t@CĂB1 ڂ̃IvV
 $strTransformation_text_plain__link = 'N\\܂BtB[hɂ̓t@CĂB1 ڂ̃IvV "http://domain.com/" ̂悤 URL ̐擪A2 ڂ̃IvV̓Ñ^Cgł';
 $strTransformation_text_plain__sql = 'eLXg̓e SQL NGƂ݂ȂA\nCCg\\܂';
 $strTransformation_text_plain__substr = '̈ꕔ݂̂\\܂B1 ڂ̃IvV͕̐擪牽XLbv邩 (ftHg 0 ł)A2 ڂ̃IvV͕\\eLXg̕ł (ftHg͕̖܂łł)B3 ڂ̃IvV͕؂l߂ƂɑO^ɕ₤ȗLł (ftHg ... ł)';
+$strTriggers = 'gK';
 $strTruncateQueries = 'NG̕\\؂l߂';
 $strTurkish = 'gR';
 $strType = '';
@@ -982,6 +974,13 @@ $strUpdateProfileMessage = 'vt@CXV܂';
 $strUpdateQuery = 'NGXV';
 $strUpdComTab = 'column_comments e[u̍XV@ɂĂ̓hLg';
 $strUpgrade = '%s  %s ȍ~ɃAbvO[hĂ';
+$strUploadErrorCantWrite = 't@CfBXNɏ߂܂B';
+$strUploadErrorExtension = 'ĝŃt@C̃Abv[hf܂B';
+$strUploadErrorFormSize = 'Abv[ht@C HTML tH[Ɏw肳Ă MAX_FILE_SIZE fBNeBu̒l𒴂Ă܂B';
+$strUploadErrorIniSize = 'Abv[ht@C php.ini Ɏw肳Ă upload_max_filesize fBNeBu̒l𒴂Ă܂B';
+$strUploadErrorNoTempDir = 'ꎞtH_܂B';
+$strUploadErrorPartial = 'Abv[ht@C͈ꕔAbv[hł܂łB';
+$strUploadErrorUnknown = 't@C̃Abv[hɗ\ȂG[܂B';
 $strUploadLimit = 'Abv[h悤Ƃt@C傫悤łB΍ɂĂ %shLg%s ';
 $strUploadsNotAllowed = '̃T[oł̓t@C̃Abv[h͂ł܂';
 $strUsage = 'gp';
@@ -1011,6 +1010,7 @@ $strViewDumpDB = 'DB ̃_v(XL[})\\';
 $strViewDump = 'e[ũ_v(XL[})\\';
 $strViewHasBeenDropped = 'r[ %s j܂';
 $strViewMaxExactCount = 'r[̍s %s z܂B%shLg%s ';
+$strViewName = 'VIEW ̖O';
 $strView = 'r[';
 
 $strWebServerUploadDirectory = 'EFuT[õAbv[hfBNg';
@@ -1024,7 +1024,6 @@ $strWriteRequests = '݃NGXg';
 $strWrongUser = '[UȂpX[hԈĂ܂B<br />ANZX͋ۂ܂';
 
 $strXkana = 'SpJi֕ϊ'; // convert to X208-kana
-$strXMLOptions = 'XMLIvV';
 $strXML = 'XML';
 
 $strYes = '͂';
@@ -1032,4 +1031,5 @@ $strYes = '͂';
 $strZeroRemovesTheLimit = ': IvV 0 ([)ɐݒ肷Ɛ܂';
 $strZip = '"zip `"';
 
+$strSuhosin = 'Suhosin gݍ܂Ă邽ߖ肪\܂Bڂ %sdocumentation%s B';  
 ?>
