@@ -1,5 +1,5 @@
 <?php
-/* $Id: japanese-utf-8.inc.php 9925 2007-02-05 17:53:36Z lem9 $ */
+/* $Id: japanese-utf-8.inc.php 11122 2008-02-13 12:33:49Z lem9 $ */
 
 /**
  * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
@@ -70,7 +70,6 @@ $strAscending = '昇順';
 $strAtBeginningOfTable = 'テーブルの先頭';
 $strAtEndOfTable = 'テーブルの末尾';
 $strAttr = '属性';
-$strAutodetect = '自動検知する';
 $strAutomaticLayout = '自動レイアウト';
 
 $strBack = '戻る';
@@ -159,6 +158,7 @@ $strConnectionError = '接続できません: 設定が無効です';
 $strConnections = '接続';
 $strConstraintsForDumped = 'ダンプしたテーブルの制約';
 $strConstraintsForTable = 'テーブルの制約';
+$strControluserFailed = '設定ファイルに定義されている管理ユーザ(controluser)での接続に失敗しました';
 $strCookiesRequired = 'クッキーを有効にしてください';
 $strCopy = 'コピー';
 $strCopyDatabaseOK = 'データベース %s を %s にコピーしました';
@@ -184,8 +184,6 @@ $strCreationDates = '作成/更新/検査日';
 $strCriteria = '条件';
 $strCroatian = 'クロアチア語';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV オプション';
-$strCSVOptions = 'CSV オプション';
 $strCyrillic = 'キリル文字ロシア語';
 $strCzech = 'チェコ語';
 $strCzechSlovak = 'チェコのスロバキア語';
@@ -196,7 +194,6 @@ $strDatabase = 'データベース';
 $strDatabaseEmpty = 'データベース名が空です!';
 $strDatabaseExportOptions = 'データベースエクスポートオプション';
 $strDatabaseHasBeenDropped = 'データベース %s を削除しました';
-$strDatabaseNoTable = 'このデータベースにはテーブルがありません!';
 $strDatabases = 'データベース';
 $strDatabasesDropped = 'データベース %s を正常に削除しました';
 $strDatabasesStats = 'データベースの統計';
@@ -241,7 +238,6 @@ $strDisplayOrder = '表示順:';
 $strDisplayPDF = 'PDF スキーマを表示する';
 $strDoAQuery = '"query by example"を実行 (ワイルドカード: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL オプション';
 $strDocu = 'ドキュメント';
 $strDoYouReally = '本当に実行しますか?';
 $strDrop = '削除';
@@ -279,8 +275,8 @@ $strErrorSaveTable = 'デザイナの座標を保存するときにエラーが
 $strEscapeWildcards = '_ や % というワイルドカードを文字として使用するときは \ でエスケープしてください';
 $strEsperanto = 'エスペラント語';
 $strEstonian = 'エストニア語';
+$strEvent = 'イベント';
 $strExcelEdition = 'Excel のエディション';
-$strExcelOptions = 'Excel のオプション';
 $strExecuteBookmarked = 'ブックマークされたクエリを実行する';
 $strExplain = 'EXPLAIN で確認';
 $strExport = 'エクスポート';
@@ -292,8 +288,8 @@ $strExtra = 'その他';
 $strFailedAttempts = '失敗回数';
 $strField = 'フィールド';
 $strFieldHasBeenDropped = 'フィールド %s を削除しました';
+$strFieldInsertFromFileTempDirNotExists = 'アップロードされたファイルの移動に失敗しました。FAQ 1.11 をご覧ください。';
 $strFields = 'フィールド';
-$strFieldsEmpty = ' フィールド数が空です。 ';
 $strFieldsEnclosedBy = 'フィールド囲み記号';
 $strFieldsEscapedBy = 'フィールドのエスケープ記号';
 $strFieldsTerminatedBy = 'フィールド区切り記号';
@@ -305,6 +301,7 @@ $strFileNameTemplateDescriptionDatabase = 'データベース名';
 $strFileNameTemplateDescriptionServer = 'サーバ名';
 $strFileNameTemplateDescriptionTable = 'テーブル名';
 $strFileNameTemplateRemember = 'テンプレートを記憶させる';
+$strFiles = 'ファイル';
 $strFileToImport = 'インポートするファイル';
 $strFixed = '固定';
 $strFlushPrivilegesNote = '注意: phpMyAdmin は MySQL の特権テーブルから直接ユーザ特権を取得しますが、手作業で特権を更新した場合は phpMyAdmin が利用しているテーブルの内容とサーバの特権の内容が一致しなくなることがありますので、作業を続ける前に %s特権リロード%s をしてください';
@@ -341,7 +338,7 @@ $strHasBeenCreated = 'を作成しました';
 $strHaveToShow = '最低ひとつは表示するカラムを選択してください';
 $strHebrew = 'ヘブライ語';
 $strHelp = 'ヘルプ';
-$strHexForBinary = 'バイナリフィールドでは 16 進数を使用する';
+$strHexForBLOB = 'BLOBに16進数表記を利用する';
 $strHide         = '隠す';
 $strHideShowAll = 'すべて隠す/表示';
 $strHideShowNoRelation = 'リレーションのないテーブルを隠す/表示';
@@ -350,9 +347,7 @@ $strHomepageOfficial = 'phpMyAdmin のオフィシャルサイト';
 $strHost = 'ホスト';
 $strHostEmpty = 'ホスト名が空です!';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 エクスポートオプション';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 エクスポートオプション';
 $strHungarian = 'ハンガリー語';
 
 $strIcelandic = 'アイスランド語';
@@ -369,13 +364,11 @@ $strImportFormat = 'インポートするファイルの形式';
 $strImportSuccessfullyFinished = 'インポートは正常終了しました。%d 個のクエリを実行しました';
 $strIndex = 'インデックス';
 $strIndexes = 'インデックスサイズ';
+$strIndexesSeemEqual = '以下のインデックスは同じもののように思われます。いずれかを削除してください :';
 $strIndexHasBeenDropped = 'インデックス %s を削除しました';
 $strIndexName = 'インデックス名:';
 $strIndexType = 'インデックスの種類:';
-$strIndexWarningMultiple = '%s というキーがカラム `%s` に複数作成されました';
-$strIndexWarningPrimary = 'カラム `%s` に PRIMARY キーと INDEX キーを両方指定することはできません';
 $strIndexWarningTable = 'テーブル `%s` のインデックスに問題があります';
-$strIndexWarningUnique = 'カラム `%s` に UNIQUE キーと INDEX キーを両方指定することはできません';
 $strInnoDBAutoextendIncrementDesc = 'スペースがいっぱいになったときに自動的にテーブルを拡張する場合に追加されるテーブルサイズ';
 $strInnoDBAutoextendIncrement = '自動拡張時に追加されるテーブルサイズ';
 $strInnoDBBufferPoolSize = 'バッファプールのサイズ';
@@ -426,7 +419,6 @@ $strKorean = '韓国語';
 
 $strLandscape = '横向き';
 $strLanguage = '言語';
-$strLanguageFileNotFound = '言語ファイル「%1$s」が見つかりません';
 $strLanguageUnknown = '言語ファイルが登録されていません: %1$s';
 $strLatchedPages = 'ラッチされているページ';
 $strLatexCaption = 'テーブルのキャプション';
@@ -436,10 +428,8 @@ $strLatexContinuedCaption = 'テーブルのキャプション(続き)';
 $strLatexIncludeCaption = 'テーブルのキャプションを含める';
 $strLatexLabel = 'ラベルキー';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX オプション';
 $strLatexStructure = 'テーブル __TABLE__ の構造';
 $strLatvian = 'ラトビア語';
-$strLDIImportOptions = 'LOAD DATA で CSV インポートするときのオプション';
 $strLDI = 'LOAD DATA する CSV';
 $strLDILocal = 'LOCAL キーワードを使用する';
 $strLengthSet = '長さ/値';
@@ -497,6 +487,7 @@ $strMyISAMSortBufferSizeDesc = 'REPAIR TABLE の最中に MyISAM のインデッ
 $strMySQLCharset = 'MySQL の文字セット';
 $strMysqlClientVersion = 'MySQL クライアントのバージョン';
 $strMySQLConnectionCollation = 'MySQL の接続照合順序';
+$strMysqlLibDiffersServerVersion = 'お使いの PHP MySQL ライブラリのバージョン %s が MySQL サーバのバージョン %s と異なります。これは予期しない不具合を起こす可能性があります。';
 $strMySQLSaid = 'MySQLのメッセージ: ';
 $strMySQLShowProcess = 'MySQL プロセスの表示';
 $strMySQLShowStatus = 'MySQL のランタイム情報';
@@ -543,13 +534,12 @@ $strNumTables = 'テーブル';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = 'スプレッドシートを開く';
-$strOpenDocumentSpreadsheetOptions = 'スプレッドシートオプション';
 $strOpenDocumentText = 'テキストを開く';
-$strOpenDocumentTextOptions = 'テキストオプション';
 $strOpenNewWindow = '別ウィンドウで開く';
 $strOperations = '操作';
 $strOperator = '演算子';
 $strOptimizeTable = 'テーブルを最適化する';
+$strOptions = 'オプション';
 $strOr = 'または';
 $strOverhead = 'オーバーヘッド';
 $strOverwriteExisting = '既存のファイルは上書き';
@@ -567,7 +557,6 @@ $strPasswordNotSame = 'パスワードが異なっています!';
 $strPdfDbSchema = 'データベース %s のスキーマ - ページ %s';
 $strPdfInvalidTblName = '"%s" テーブルは存在しません!';
 $strPdfNoTables = 'テーブルがありません';
-$strPDFOptions = 'PDF オプション';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(ひとつのテーブルのデータを含むレポートを生成します)';
 $strPDFReportTitle = 'レポートのタイトル';
@@ -635,6 +624,7 @@ $strPrivilegesReloaded = '特権を正常にリロードしました';
 $strProcedures = 'プロシジャ';
 $strProcesses = 'プロセス';
 $strProcesslist = 'プロセス一覧';
+$strProfiling = 'プロファイリング';
 $strProtocolVersion = 'プロトコルバージョン';
 $strPutColNames = '1 行目にフィールド名を追加する';
 
@@ -676,12 +666,15 @@ $strReplaceTable = 'テーブルデータを差し替えるファイル';
 $strReplication = 'レプリケーション';
 $strReset = 'リセット';
 $strResourceLimits = 'リソースの制限';
+$strRestartInsertion = '%s 行から挿入を再開する';
 $strReType = 'もう一度入力してください';
 $strRevoke = '取り消し';
 $strRevokeAndDelete = '特権をすべて取り消してユーザを削除する';
 $strRevokeAndDeleteDescr = 'USAGE 特権については特権をリロードするまで残ります';
 $strRevokeMessage = '%s の特権を取り消しました';
 $strRomanian = 'ルーマニア語';
+$strRoutineReturnType = '返り値の種類';
+$strRoutines = 'ルーチン';
 $strRowLength = '行の長さ';
 $strRows = '行';
 $strRowsFrom = '開始行';
@@ -733,6 +726,7 @@ $strServerTabVariables = '変数';
 $strServerTrafficNotes = '<b>サーバトラフィック</b>: これらの表は MySQL サーバ起動以後のネットワークトラフィックの統計です';
 $strServerVars = 'サーバ変数と設定値';
 $strServerVersion = 'サーバのバージョン';
+$strSessionStartupErrorGeneral = 'エラーが出たためセッションを開始できませんでした。PHP やウェブサーバのログファイルに出ているエラーを確認して、PHP を正しく設定してください。';
 $strSessionValue = 'セッション値';
 $strSetEnumVal = 'フィールド種別が「enum」ないし「set」の場合の値の書式: \'a\',\'b\',\'c\'...<br />バックスラッシュ("\")やシングルクォート("\'")を含める必要がある場合は ( \\\\xyz や a\\\'b のように) その前にバックスラッシュを付けてください';
 $strShowAll = 'すべて表示';
@@ -822,7 +816,7 @@ $strShowStatusKey_readsDescr = 'ディスクからキーブロックを物理読
 $strShowStatusKey_write_requestsDescr = 'キャッシュにキーブロックを書き込んだリクエストの数';
 $strShowStatusKey_writesDescr = 'ディスクにキーブロックを物理書き込みした回数';
 $strShowStatusLast_query_costDescr = 'クエリオプティマイザーの計算による、最後にコンパイルされたクエリの総コスト。クエリのプランを変えたときにコストがどう変わるか比較するときに便利です。デフォルト値の 0 はまだ一度もクエリをコンパイルしていないという意味です';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'INSERT DELAY キューの中で書き込まれるのを待っている行数';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'INSERT DELAYED キューの中で書き込まれるのを待っている行数';
 $strShowStatusOpened_tablesDescr = '開いているテーブルの数。開いているテーブルが多い場合はおそらくテーブルキャッシュの値が小さすぎます';
 $strShowStatusOpen_filesDescr = '開いているファイルの数';
 $strShowStatusOpen_streamsDescr = '開いているストリームの数 (主にログの記録用です)';
@@ -877,8 +871,6 @@ $strSpanish = 'スペイン語';
 $strSplitWordsWithSpace = '各単語は空白文字(" ")で区切ってください';
 $strSQLCompatibility = 'SQL互換モード';
 $strSQLExportType = 'エクスポート形式';
-$strSQLImportOptions = 'SQL オプション';
-$strSQLOptions = 'SQL オプション';
 $strSQLParserBugMessage = 'SQL パーサにバグが見つかることもありえますが、まずはクエリをよく見て引用符の数や種類に間違いがないか確認してください。クォートされていないテキスト領域にバイナリファイルをアップロードしたからクエリが失敗したということもありえます。MySQL のコマンドラインインタフェースを利用してクエリを実行してみてもよいでしょう。下に MySQL サーバのエラー出力が出ているようなら問題の解析に役立つかもしれません。それでも解決しないか、コマンドラインでは成功するのにパーサでは失敗する場合は、SQL クエリの入力データを実際に問題を起こしているクエリひとつに絞り込んでから、以下の「CUT」セクションにデータを添えてバグ報告を送ってください:';
 $strSQLParserUserError = 'SQL にエラーがあるようです。下に MySQL サーバのエラー出力が出ているようなら問題の解析に役立つかもしれません';
 $strSQLQuery = '実行した SQL';
@@ -900,7 +892,6 @@ $strStrucCSV = 'CSV データ';
 $strStrucData = '構造とデータ';
 $strStrucExcelCSV = 'MS Excel 用の CSV';
 $strStrucNativeExcel = 'MS Excel のネイティブ形式';
-$strStrucNativeExcelOptions = 'Excel のネイティブエクスポートオプション';
 $strStrucOnly = '構造のみ';
 $strStructPropose = 'テーブル構造を確認する';
 $strStructure = '構造';
@@ -966,6 +957,7 @@ $strTransformation_text_plain__imagelink = '画像とリンクを表示します
 $strTransformation_text_plain__link = 'リンクを表示します。フィールドにはファイル名を入れてください。1 つ目のオプションは "http://domain.com/" のような URL の先頭部分、2 つ目のオプションはリンクのタイトルです';
 $strTransformation_text_plain__sql = 'テキストの内容を SQL クエリとみなし、構文ハイライト表示します';
 $strTransformation_text_plain__substr = '文字列の一部のみを表示します。1 つ目のオプションは文字列の先頭から何文字スキップするか (デフォルトは 0 です)、2 つ目のオプションは表示するテキストの文字数です (デフォルトは文字列の末尾までです)。3 つ目のオプションは文字列を切り詰めるときに前／後に補う省略記号です (デフォルトは ... です)';
+$strTriggers = 'トリガ';
 $strTruncateQueries = 'クエリの表示を切り詰める';
 $strTurkish = 'トルコ語';
 $strType = '種別';
@@ -982,6 +974,13 @@ $strUpdateProfileMessage = 'プロファイルを更新しました';
 $strUpdateQuery = 'クエリを更新する';
 $strUpdComTab = 'column_comments テーブルの更新方法についてはドキュメントをご覧ください';
 $strUpgrade = '%s を %s 以降にアップグレードしてください';
+$strUploadErrorCantWrite = 'ファイルをディスクに書き込めません。';
+$strUploadErrorExtension = '拡張のせいでファイルのアップロードが中断されました。';
+$strUploadErrorFormSize = 'アップロードしたファイルは HTML フォームに指定されている MAX_FILE_SIZE ディレクティブの値を超えています。';
+$strUploadErrorIniSize = 'アップロードしたファイルは php.ini に指定されている upload_max_filesize ディレクティブの値を超えています。';
+$strUploadErrorNoTempDir = '一時フォルダが見つかりません。';
+$strUploadErrorPartial = 'アップロードしたファイルは一部分しかアップロードできませんでした。';
+$strUploadErrorUnknown = 'ファイルのアップロード中に予期しないエラーが発生しました。';
 $strUploadLimit = 'アップロードしようとしたファイルが大きすぎるようです。対策については %sドキュメント%s をご覧ください';
 $strUploadsNotAllowed = 'このサーバではファイルのアップロードはできません';
 $strUsage = '使用量';
@@ -1012,6 +1011,7 @@ $strViewDumpDatabases = 'データベースのダンプ(スキーマ)表示';
 $strViewDumpDB = 'DB のダンプ(スキーマ)表示';
 $strViewHasBeenDropped = 'ビュー %s を破棄しました';
 $strViewMaxExactCount = 'ビューの行数が %s を越えました。%sドキュメント%s をご覧ください';
+$strViewName = 'VIEW の名前';
 
 $strWebServerUploadDirectory = 'ウェブサーバ上のアップロードディレクトリ';
 $strWebServerUploadDirectoryError = '指定したアップロードディレクトリが利用できません';
@@ -1024,7 +1024,6 @@ $strWriteRequests = '書き込みリクエスト数';
 $strWrongUser = 'ユーザ名ないしパスワードが間違っています。<br />アクセスは拒否されました';
 
 $strXkana = '全角カナへ変換する'; // convert to X208-kana
-$strXMLOptions = 'XMLオプション';
 $strXML = 'XML';
 
 $strYes = 'はい';
@@ -1032,4 +1031,5 @@ $strYes = 'はい';
 $strZeroRemovesTheLimit = '注意: オプションを 0 (ゼロ)に設定すると制限を解除します';
 $strZip = '"zip 形式"';
 
+$strSuhosin = 'Suhosin が組み込まれているため問題が発生する可能性があります。詳しくは %sdocumentation%s をご覧ください。';  
 ?>
