@@ -3,7 +3,7 @@
 /**
  * Misc functions used all over the scripts.
  *
- * @version $Id: common.lib.php 10553 2007-08-11 11:53:01Z lem9 $
+ * @version $Id: common.lib.php 11082 2008-01-25 17:42:23Z lem9 $
  */
 
 /**
@@ -542,62 +542,6 @@ function PMA_mysqlDie($error_message = '', $the_query = '',
     echo '<code>' . "\n"
         . $error_message . "\n"
         . '</code><br />' . "\n";
-
-    // feature request #1036254:
-    // Add a link by MySQL-Error #1062 - Duplicate entry
-    // 2004-10-20 by mkkeck
-    // 2005-01-17 modified by mkkeck bugfix
-    if (substr($error_message, 1, 4) == '1062') {
-        // get the duplicate entry
-
-        // get table name
-        /**
-         * @todo what would be the best delimiter, while avoiding special
-         * characters that can become high-ascii after editing, depending
-         * upon which editor is used by the developer?
-         */
-        $error_table = array();
-        if (preg_match('@ALTER\s*TABLE\s*\`([^\`]+)\`@iu', $the_query, $error_table)) {
-            $error_table = $error_table[1];
-        } elseif (preg_match('@INSERT\s*INTO\s*\`([^\`]+)\`@iu', $the_query, $error_table)) {
-            $error_table = $error_table[1];
-        } elseif (preg_match('@UPDATE\s*\`([^\`]+)\`@iu', $the_query, $error_table)) {
-            $error_table = $error_table[1];
-        } elseif (preg_match('@INSERT\s*\`([^\`]+)\`@iu', $the_query, $error_table)) {
-            $error_table = $error_table[1];
-        }
-
-        // get fields
-        $error_fields = array();
-        if (preg_match('@\(([^\)]+)\)@i', $the_query, $error_fields)) {
-            $error_fields = explode(',', $error_fields[1]);
-        } elseif (preg_match('@(`[^`]+`)\s*=@i', $the_query, $error_fields)) {
-            $error_fields = explode(',', $error_fields[1]);
-        }
-        if (is_array($error_table) || is_array($error_fields)) {
-
-            // duplicate value
-            $duplicate_value = array();
-            preg_match('@\'([^\']+)\'@i', $tmp_mysql_error, $duplicate_value);
-            $duplicate_value = $duplicate_value[1];
-
-            $sql = '
-                 SELECT *
-                   FROM ' . PMA_backquote($error_table) . '
-                  WHERE CONCAT_WS("-", ' . implode(', ', $error_fields) . ')
-                        = "' . PMA_sqlAddslashes($duplicate_value) . '"
-               ORDER BY ' . implode(', ', $error_fields);
-            unset($error_table, $error_fields, $duplicate_value);
-
-            echo '        <form method="post" action="import.php" style="padding: 0; margin: 0">' ."\n"
-                .'            <input type="hidden" name="sql_query" value="' . htmlspecialchars($sql) . '" />' . "\n"
-                .'            ' . PMA_generate_common_hidden_inputs($db, $table) . "\n"
-                .'            <input type="submit" name="submit" value="' . $GLOBALS['strBrowse'] . '" />' . "\n"
-                .'        </form>' . "\n";
-            unset($sql);
-        }
-    } // end of show duplicate entry
-
     echo '</div>';
     echo '<fieldset class="tblFooters">';
 
@@ -628,7 +572,7 @@ function PMA_mysqlDie($error_message = '', $the_query = '',
  *
  * @access  private
  */
-function PMA_convert_using($string, $mode='unquoted')
+function PMA_convert_using($string, $mode='unquoted', $force_utf8 = false)
 {
     if ($mode == 'quoted') {
         $possible_quote = "'";
@@ -637,8 +581,14 @@ function PMA_convert_using($string, $mode='unquoted')
     }
 
     if (PMA_MYSQL_INT_VERSION >= 40100) {
-        list($conn_charset) = explode('_', $GLOBALS['collation_connection']);
-        $converted_string = "CONVERT(" . $possible_quote . $string . $possible_quote . " USING " . $conn_charset . ")";
+        if ($force_utf8) {
+            $charset = 'utf8';
+            $collate = ' COLLATE utf8_bin';
+        } else {
+            list($charset) = explode('_', $GLOBALS['collation_connection']);
+            $collate = '';
+        }
+        $converted_string = "CONVERT(" . $possible_quote . $string . $possible_quote . " USING " . $charset . ")" . $collate;
     } else {
         $converted_string = $possible_quote . $string . $possible_quote;
     }
@@ -924,6 +874,11 @@ function PMA_reloadNavigation()
 
     // Reloads the navigation frame via JavaScript if required
     if (isset($GLOBALS['reload']) && $GLOBALS['reload']) {
+        // one of the reasons for a reload is when a table is dropped
+        // in this case, get rid of the table limit offset, otherwise
+        // we have a problem when dropping a table on the last page
+        // and the offset becomes greater than the total number of tables
+        unset($_SESSION['userconf']['table_limit_offset']);
         echo "\n";
         $reload_url = './navigation.php?' . PMA_generate_common_url($GLOBALS['db'], '', '&');
         ?>
@@ -1264,6 +1219,25 @@ function PMA_showMessage($message, $sql_query = null)
 } // end of the 'PMA_showMessage()' function
 
 
+/**
+ * Verifies if current MySQL server supports profiling 
+ *
+ * @access  public
+ * @return  boolean whether profiling is supported 
+ *
+ * @author   Marc Delisle 
+ */
+function PMA_profilingSupported() {
+    // 5.0.37 has profiling but for example, 5.1.20 does not
+    // (avoid a trip to the server for MySQL before 5.0.37)
+    // and do not set a constant as we might be switching servers
+    if (defined('PMA_MYSQL_INT_VERSION') && PMA_MYSQL_INT_VERSION >= 50037 && PMA_DBI_fetch_value("SHOW VARIABLES LIKE 'profiling'")) {
+        return true;
+    } else {
+        return false;
+    }
+}
+
 /**
  * Displays a form with the Profiling checkbox 
  *
@@ -1273,12 +1247,10 @@ function PMA_showMessage($message, $sql_query = null)
  * @author   Marc Delisle 
  */
 function PMA_profilingCheckbox($sql_query) {
-    // 5.0.37 has profiling but for example, 5.1.20 does not
-    // (avoid doing a fetch_value for MySQL before 5.0.37)
-    if (PMA_MYSQL_INT_VERSION >= 50037 && PMA_DBI_fetch_value("SHOW VARIABLES LIKE 'profiling'")) {
-        echo '<form action="sql.php" method="post" />' . "\n";
+    if (PMA_profilingSupported()) {
+        echo '<form action="sql.php" method="post">' . "\n";
         echo PMA_generate_common_hidden_inputs($GLOBALS['db'], $GLOBALS['table']);
-        echo '<input type="hidden" name="sql_query" value="' . $sql_query . '" />' . "\n";
+        echo '<input type="hidden" name="sql_query" value="' . htmlspecialchars($sql_query) . '" />' . "\n";
         echo '<input type="hidden" name="profiling_form" value="1" />' . "\n";
         echo '<input type="checkbox" name="profiling" id="profiling"' . (isset($_SESSION['profiling']) ? ' checked="checked"' : '') . ' onclick="this.form.submit();" /><label for="profiling">' . $GLOBALS['strProfiling'] . '</label>' . "\n";
         echo '<noscript><input type="submit" value="' . $GLOBALS['strGo'] . '" /></noscript>' . "\n";
@@ -1342,8 +1314,12 @@ function PMA_formatByteDown($value, $limes = 6, $comma = 0)
     } // end for
 
     if ($unit != $GLOBALS['byteUnits'][0]) {
-        $return_value = PMA_formatNumber($value, 5, $comma);
+        // if the unit is not bytes (as represented in current language)
+        // reformat with max length of 5
+        // 4th parameter=true means do not reformat if value < 1
+        $return_value = PMA_formatNumber($value, 5, $comma, true);
     } else {
+        // do not reformat, just handle the locale
         $return_value = PMA_formatNumber($value, 0);
     }
 
@@ -1413,7 +1389,7 @@ function PMA_formatNumber($value, $length = 3, $comma = 0, $only_down = false)
         $length = 3 - $comma;
     }
 
-    // check for negativ value to retain sign
+    // check for negative value to retain sign
     if ($value < 0) {
         $sign = '-';
         $value = abs($value);
@@ -1505,6 +1481,7 @@ function PMA_localisedDate($timestamp = -1, $format = '')
  * returns a tab for tabbed navigation.
  * If the variables $link and $args ar left empty, an inactive tab is created
  *
+ * @uses    $GLOBALS['PMA_PHP_SELF']
  * @uses    $GLOBALS['strEmpty']
  * @uses    $GLOBALS['strDrop']
  * @uses    $GLOBALS['active_page']
@@ -1548,7 +1525,7 @@ function PMA_getTab($tab)
         } elseif (!empty($tab['active'])
           || (isset($GLOBALS['active_page'])
                && $GLOBALS['active_page'] == $tab['link'])
-          || (basename(PMA_getenv('PHP_SELF')) == $tab['link'] && empty($tab['warning'])))
+          || (basename($GLOBALS['PMA_PHP_SELF']) == $tab['link'] && empty($tab['warning'])))
         {
             $tab['class'] = 'active';
         }
@@ -1844,6 +1821,7 @@ function PMA_flipstring($string, $Separator = "<br />\n")
  * @todo    use PMA_fatalError() if $die === true?
  * @uses    PMA_getenv()
  * @uses    header_meta_style.inc.php
+ * @uses    $GLOBALS['PMA_PHP_SELF']
  * basename
  * @param   array   The names of the parameters needed by the calling
  *                  script.
@@ -1865,7 +1843,7 @@ function PMA_checkParameters($params, $die = true, $request = true)
         $checked_special = false;
     }
 
-    $reported_script_name = basename(PMA_getenv('PHP_SELF'));
+    $reported_script_name = basename($GLOBALS['PMA_PHP_SELF']);
     $found_error = false;
     $error_message = '';
 
@@ -2096,8 +2074,8 @@ function PMA_pageselector($url, $rows, $pageNow = 1, $nbTotalPage = 1,
     $showAll = 200, $sliceStart = 5, $sliceEnd = 5, $percent = 20,
     $range = 10, $prompt = '')
 {
-    $gotopage = $prompt 
-              . ' <select name="goToPage" onchange="goToUrl(this, \''
+    $gotopage = $prompt
+              . ' <select name="pos" onchange="goToUrl(this, \''
               . $url . '\');">' . "\n";
     if ($nbTotalPage < $showAll) {
         $pages = range(1, $nbTotalPage);
@@ -2161,24 +2139,25 @@ function PMA_pageselector($url, $rows, $pageNow = 1, $nbTotalPage = 1,
         $gotopage .= '                <option ' . $selected . ' value="' . (($i - 1) * $rows) . '">' . $i . '</option>' . "\n";
     }
 
-    $gotopage .= ' </select>';
+    $gotopage .= ' </select><noscript><input type="submit" value="' . $GLOBALS['strGo'] . '" /></noscript>';
+
 
     return $gotopage;
 } // end function
 
 
 /**
- * Generate navigation for a list 
+ * Generate navigation for a list
  *
- * @todo    use $pos from $_url_params 
+ * @todo    use $pos from $_url_params
  * @uses    $GLOBALS['strPageNumber']
  * @uses    range()
- * @param   integer     number of elements in the list 
- * @param   integer     current position in the list 
- * @param   array       url parameters 
- * @param   string      script name for form target 
- * @param   string      target frame 
- * @param   integer     maximum number of elements to display from the list 
+ * @param   integer     number of elements in the list
+ * @param   integer     current position in the list
+ * @param   array       url parameters
+ * @param   string      script name for form target
+ * @param   string      target frame
+ * @param   integer     maximum number of elements to display from the list
  *
  * @access  public
  */
@@ -2213,7 +2192,7 @@ function PMA_listNavigator($count, $pos, $_url_params, $script, $frame, $max_cou
                 . $caption2 . '</a>';
         }
 
-        echo '<form action="./' . $script . '" method="post">' . "\n";
+        echo "\n", '<form action="./', basename($script), '" method="post" target="', $frame, '">', "\n";
         echo PMA_generate_common_hidden_inputs($_url_params);
         echo PMA_pageselector(
             $script . PMA_generate_common_url($_url_params) . '&',
@@ -2235,7 +2214,7 @@ function PMA_listNavigator($count, $pos, $_url_params, $script, $frame, $max_cou
                 $title4   = '';
             } // end if... else...
             $_url_params['pos'] = $pos + $max_count;
-            echo '<a' . $title3 . ' href="' . $script 
+            echo '<a' . $title3 . ' href="' . $script
                 . PMA_generate_common_url($_url_params) . '" target="' . $frame . '">'
                 . $caption3 . '</a>';
             $_url_params['pos'] = floor($count / $max_count) * $max_count;
