@@ -3,7 +3,7 @@
 /**
  * @todo    we must handle the case if sql.php is called directly with a query
  *          what returns 0 rows - to prevent cyclic redirects or includes
- * @version $Id: sql.php 10468 2007-06-27 21:01:13Z lem9 $
+ * @version $Id: sql.php 11024 2007-12-29 20:38:27Z lem9 $
  */
 
 /**
@@ -109,16 +109,6 @@ if (isset($store_bkm)) {
     PMA_sendHeaderLocation($cfg['PmaAbsoluteUri'] . $goto);
 } // end if
 
-
-/**
- * Gets the true sql query
- */
-// $sql_query has been urlencoded in the confirmation form for drop/delete
-// queries or in the navigation bar for browsing among records
-if (isset($btnDrop) || isset($navig)) {
-    $sql_query = urldecode($sql_query);
-}
-
 /**
  * Parse and analyze the query
  */
@@ -184,7 +174,7 @@ if ($do_confirm) {
     echo '<form action="sql.php" method="post">' . "\n"
         .PMA_generate_common_hidden_inputs($db, $table);
     ?>
-    <input type="hidden" name="sql_query" value="<?php echo urlencode($sql_query); ?>" />
+    <input type="hidden" name="sql_query" value="<?php echo htmlspecialchars($sql_query); ?>" />
     <input type="hidden" name="zero_rows" value="<?php echo isset($zero_rows) ? PMA_sanitize($zero_rows) : ''; ?>" />
     <input type="hidden" name="goto" value="<?php echo $goto; ?>" />
     <input type="hidden" name="back" value="<?php echo isset($back) ? PMA_sanitize($back) : ''; ?>" />
@@ -214,14 +204,14 @@ if ($do_confirm) {
 
 
 // Defines some variables
-// A table has to be created or renamed -> left frame should be reloaded
+// A table has to be created, renamed, dropped -> navi frame should be reloaded
 /**
  * @todo use the parser/analyzer
  */
 
 if (empty($reload)
     && preg_match('/^(CREATE|ALTER|DROP)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i', $sql_query)) {
-    $reload           = 1;
+    $reload = 1;
 }
 
 // SK -- Patch: $is_group added for use in calculation of total number of
@@ -255,18 +245,18 @@ if ($is_select) { // see line 141
     }
 } elseif (preg_match('@^UPDATE[[:space:]]+@i', $sql_query)) {
     $is_affected = true;
-} elseif (preg_match('@^SHOW[[:space:]]+@i', $sql_query)) {
+} elseif (preg_match('@^[[:space:]]*SHOW[[:space:]]+@i', $sql_query)) {
     $is_show     = true;
 } elseif (preg_match('@^(CHECK|ANALYZE|REPAIR|OPTIMIZE)[[:space:]]+TABLE[[:space:]]+@i', $sql_query)) {
     $is_maint    = true;
 }
 
 // Do append a "LIMIT" clause?
-if ((!$cfg['ShowAll'] || $_SESSION['userconf']['max_rows'] != 'all')
- && !($is_count || $is_export || $is_func || $is_analyse)
+if ((! $cfg['ShowAll'] || $_SESSION['userconf']['max_rows'] != 'all')
+ && ! ($is_count || $is_export || $is_func || $is_analyse)
  && isset($analyzed_sql[0]['queryflags']['select_from'])
- && !isset($analyzed_sql[0]['queryflags']['offset'])
- && !preg_match('@[[:space:]]LIMIT[[:space:]0-9,-]+(;)?$@i', $sql_query)
+ && ! isset($analyzed_sql[0]['queryflags']['offset'])
+ && empty($analyzed_sql[0]['limit_clause'])
  ) {
     $sql_limit_to_append = ' LIMIT ' . $_SESSION['userconf']['pos'] . ', ' . $_SESSION['userconf']['max_rows'] . " ";
 
@@ -319,7 +309,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
     unset($result);
     $num_rows = 0;
 } else {
-    if (isset($_SESSION['profiling'])) {
+    if (isset($_SESSION['profiling']) && PMA_profilingSupported()) {
         PMA_DBI_query('SET PROFILING=1;');
     }
         
@@ -354,7 +344,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
     }
 
     // Grabs the profiling results
-    if (isset($_SESSION['profiling'])) {
+    if (isset($_SESSION['profiling']) && PMA_profilingSupported() ) {
         $profiling_results = PMA_DBI_fetch_result('SHOW PROFILE;');
     }
         
